Documentation
¶
Index ¶
- func Autocomplete(executor Executor) bool
- func Do(ctx context.Context, name string, executor Executor) error
- func EnsureTool(ctx context.Context, tool Tool) error
- func GetName(ctx context.Context) string
- func InstallTools(ctx context.Context, tools ...map[string]Tool) error
- type CommandFunc
- type DepsFunc
- type Executor
- type Tool
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Autocomplete ¶
Autocomplete serves bash autocomplete functionality. Returns true if autocomplete was requested and false otherwise.
func EnsureTool ¶ added in v1.5.1
EnsureTool ensures that tool exists, if not it is installed
Types ¶
type CommandFunc ¶
CommandFunc represents executable command
type DepsFunc ¶
type DepsFunc func(deps ...interface{})
DepsFunc represents function for executing dependencies
type Executor ¶
type Executor interface {
// Paths lists all available command paths
Paths() []string
// Execute executes commands by their paths
Execute(ctx context.Context, name string, paths []string) error
}
Executor defines interface of command executor
type Tool ¶ added in v1.5.1
type Tool struct {
// Name is the name of the tool
Name string
// Version is the version of the tool
Version string
// URL is the url to the archive containing the tool
URL string
// Hash is the hash of the downloade file
Hash string
// Binaries is the list of relative paths to binaries to install in local bin folder
Binaries []string
}
Tool represents the tool to be required by the build system
Click to show internal directories.
Click to hide internal directories.